;#################################################
; U S E    S E E D S
;
;INPUT:
;none
;OUTPUT:
;Changes surrounding 9 tiles with equiped seed
;#################################################
use_seeds:
	call	locate_character
	ret	z			;can't handle a splice.  Won't draw a splice
					;exception because events will be "no_event"

	ld	hl,(tool)
	inc	hl
	ld	c,(hl)
	inc	hl
	xor	a
	ld	b,a
	or	(hl)			;tool alive?
	ret	z	

	inc	hl
	dec	(hl)
	jr	nz,still_have_seeds
	
	dec	hl
	ld	(hl),b			;kill the item, but use it this time

still_have_seeds:
	ld	hl,seed_structures
	add	hl,bc
	ld	a,(hl)
	ld	(seed_image),a
	inc	hl
	ld	a,(hl)
	ld	(seed_data),a	

	call	display_change_item	;show hands up in the air
	call	long_synchronize

	ld	hl,seed_chart
	
	ld	b,9
change_seed_tiles:
	ld	e,(hl)
	inc	hl
	ld	d,(hl)
	inc	hl
	push	de
	exx
	call	locate_character
	pop	de
	add	hl,de

	ld	a,tild
	cp	(hl)
	jr	z,write_seed
	ld	a,tldw
	cp	(hl)
	jr	z,write_watered_seed
	jr	skip_write_seed
write_seed:
seed_image = $+1
	ld	(hl),00
	inc	hl
seed_data = $+1
	ld	(hl),00
	jr	skip_write_seed
write_watered_seed:
	ld	a,(seed_image)
	inc	a
	ld	(hl),a
	inc	hl
	ld	a,(seed_data)
	set	1,a
	ld	(hl),a
skip_write_seed:
	exx
	djnz	change_seed_tiles
seeds_super_update:
	jp	super_update

;#################################################
; U S E    T O O L
;
;INPUT:
;none
;OUTPUT:
;Displays tool animation and runs tool code
;#################################################
use_tool:
	call	has_item_ret_yes

	ld	hl,(tool)

	ld	a,(hl)			;tool data address low byte
	ld	e,a
	dec	a
	jr	z,use_seeds		;run seeds
	inc	hl
	ld	d,(hl)			;tool data address high byte
	inc	hl
	inc	(hl)			;tool alive?
	dec	(hl)
	ret	z			;just in case the tool is dead, don't run it

	ex	de,hl
	ld	c,(hl)
	inc	hl
	ld	b,(hl)
	inc	hl			;hl points to state threshold

	push	bc			;we'll ret there later (tool code address)

	xor	a			;reset carry, 0
	ld	d,a
	ld	a,(gen_state)
			
	rla				;x2
	rla				;x4
	rla				;x8

	ld	e,a
	add	hl,de			;hl points to first state
	
	ld	a,2
	ld	(swap),a
beginning_double_state_overlay:
	ld	de,tool_buf		;3
	xor	a			;1	;reset carry
	ld	b,192			;2
clear_image:
	ld	(de),a			;1
	inc	de			;1
	djnz	clear_image		;2

	ld	b,192			;2
	dec	a			;1	;ld a,$FF
fill_mask:
	ld	(de),a			;1
	inc	de			;1
	djnz	fill_mask		;2	;17	(smaller than the block instructions since less than 256 reps)

	ld	c,(hl)			;c<-starting row*4
	inc	hl
	ld	a,(hl)			;a<-image height
	inc	hl
	ld	e,(hl)			;e<-image low byte
	inc	hl
	ld	d,(hl)			;d<-image high byte
	inc	hl
	push	hl
	
	ld	hl,tool_buf+192		;mask half of the tool buffer
	add	hl,bc
	push	hl			;save start address for mask
	
	ld	hl,tool_buf		;b already has 0
	add	hl,bc			;hl points to starting row in tool buf

	ld	b,a
	rr	b			;push off rightmost bit
	jr	nc,no_right_column	;if it's clear, we're skipping that sonovabitch
	xor	a			;the bit was set, so simultaneously reset carry for next shift
	jr	done_r			;and make the jump null
no_right_column:
	ld	a,3			;it's a 3 byte jump
done_r:
	ld	(right_column_mod),a	;mod the code
	rr	b			;push off the next bit
	jr	nc,no_left_column	;same deal, but this time the left column
	xor	a
	jr	done_l
no_left_column:
	ld	a,3
done_l:
	ld	(left_column_mod),a

	ld	c,b			;save rows in c (the extra bits were clipped from b)
	call	copy_tool		;copy 

	ld	b,c			;restore rows
	pop	hl			;this time hl starts on the mask half of the buffer
	call	copy_tool		;and de starts in the mask half of the image

	ld	de,((80h+4+48)*256)+24h+4
	ld	bc,tool_buf
	exx
	ld	bc,((80h+4)*256)+24h
	ld	de,tool_buf+192
	ld	hl,onvid+(4*16)+4
	call	overlay_sprite		;overlay the set sprite to cover up previous tool state

	ld	hl,swap
	dec	(hl)			;just two frames
	jr	z,tool_anim_done

use_tool_clear:
	ld	a,0DFh
	call	directin
	ld	c,a
	ld	a,$FE
	call	directin
	rra
	jr	nc,turn_down
	rra
	jr	nc,turn_left
	rra
	jr	nc,turn_right
	rra
	jr	nc,turn_up
	inc	c
	jr	nz,use_tool_clear	;if alpha's not clear, get input again
	jr	d_state_delay
turn_down:
	xor	a
	jr	tool_button_down_a
turn_left:
	ld	a,1
	jr	tool_button_down_a
turn_right:
	ld	a,2
	jr	tool_button_down_a
turn_up:
	ld	a,3
tool_button_down_a:
	ld	(gen_state),a
	inc	c
tool_byte:
	jr	z,d_state_delay
	pop	hl			;get hl off of me
	pop	bc			;get that tool off of me, it's just gonna put it again	
	jp	use_tool

d_state_delay:
	ld	a,80
	call	synchronize_skip
	pop	hl			;restore pointer to data
	jp	beginning_double_state_overlay

tool_anim_done:
	pop	hl			;remove hl
	xor	a
	ld	(item_contents),a	;make sure item is still clear
	ld	a,110
	call 	synchronize_skip		;more please
	call	super_update
	jp	locate_target_square
	
;INPUT
;c	- starting row
;a'	- ending row 
;de	- pointer to image
;hl	- pointer to item buffer with row offset
;OUTPUT
;c	- starting row*4+ending_row
;a	- ending row
copy_tool:
left_column_mod = $+1
	jr	skip_left_column		;patch a 0 or a 3
copy_tool_left_column:
	ld	a,(de)
	ld	(hl),a
	inc	de
skip_left_column:
	inc	hl
	ld	a,(de)
	ld	(hl),a
	inc	hl
	inc	de
	ld	a,(de)
	ld	(hl),a
	inc	hl
	inc	de
right_column_mod = $+1
	jr	skip_right_column		;path a 0 or a 3
copy_tool_right_column:
	ld	a,(de)
	ld	(hl),a
	inc	de
skip_right_column:
	inc	hl
	djnz	copy_tool
	ret
	
super_watering_can:
	ret	z
	xor	a
	ld	hl,water_level
	or	(hl)
	jr	z,empty_can

	ld	a,8
	add	a,(hl)
	ld	(hl),a
	
	ld	hl,water_super_update
	ld	(hl),$C9		;skip water's super update	
	push	hl

	ld	hl,(map)
	push	hl
	call	locate_target_square+3
	ld	(map),hl
	
	ld	hl,seed_chart

	ld	b,9
super_load:
	ld	e,(hl)
	inc	hl
	ld	d,(hl)
	inc	hl
	push	de
	exx
	call	locate_target_square
	pop	de
	add	hl,de
	call	use_watering_can+1	;skip ret check
	exx
	djnz	super_load

	pop	hl
	ld	(map),hl

	pop	hl
	ld	(hl),$C3	

	jr	water_super_update	

;#################################################
; U S E   W A T E R I N G    C A N
;
;INPUT:
;hl	- target square
;f	- z : splice  nz : no splice
;OUTPUT:
;Sets the watered bit in target square's flags
;and increments the image located there
;#################################################
use_watering_can:
	ret	z			;I guess don't kill their water on a splice

	inc	hl
	ld	a,61h			;refill watering can event?
	cp	(hl)
	jp	z,action		;will call refill watering can event
water_level = $+1
	ld	a,16			;default 16 spaces
	or	a
	jr	z,empty_can

	dec	a
	ld	(water_level),a

	bit	2,(hl)
	jr	z,not_plant

	bit	1,(hl)
	ret	nz			;if it's watered, get out

finish_watering:
	set	1,(hl)	
	dec	hl
	inc	(hl)
water_super_update:
	jp	super_update

empty_can:
	ld	hl,empty_message
	jp	display_fast_text

not_plant:
	dec	hl
	ld	a,tild
	cp	(hl)
	inc	hl
	jr	z,finish_watering
	ret

;#################################################
; U S E    H O E
;
;INPUT:
;hl	- target square
;f	- z : splice  nz : no splice
;OUTPUT:
;Changes dirt to tilled dirt
;#################################################
use_hoe:
	ret	z
	ld	a,dirt
	cp	(hl)
	ret	nz

	ld	(hl),tild
	jr	water_super_update

;#################################################
; U S E    A X E
;
;INPUT:
;hl	- target square
;OUTPUT:
;Changes stumps to dirt
;#################################################
use_axe:
	ret	z
	ld	a,(hl)
	cp	stmp
	ret	nz
finish_axe:
	ld	(hl),dirt
	inc	hl
	ld	(hl),00
	jr	water_super_update

;#################################################
; U S E    A X E
;
;INPUT:
;hl	- target square
;OUTPUT:
;Changes various tiles to dirt
;#################################################
use_hammer:
	ret	z
	ld	a,(hl)
	cp	drok
	jr	z,finish_axe
	cp	tild
	jr	z,finish_axe
	cp	tldw
	jr	z,finish_axe
	cp	lrok
	jr	z,finish_axe
	ret